@@ -6,7 +6,7 @@ use Carp        qw[];
 use Time::HiRes qw[];
 
 BEGIN {
-    our $VERSION = '0.14';
+    our $VERSION = '0.15';
     require XSLoader; XSLoader::load(__PACKAGE__, $VERSION);
 }
 
@@ -107,5 +107,8 @@ sub THAW {
     return $class->from_string($string);
 }
 
+# Alias
+*with_offset = \&with_offset_same_instant;
+
 1;
 
